@@ -1,10 +1,14 @@
 import asyncio
+import json
 import os
 import re
 import subprocess
 
 import click
 import psutil
+from prettytable import PrettyTable, MARKDOWN
+
+from src.utils.convertUtils import byte_length_format
 
 
 async def asyncGetScreenfetch():
@@ -120,9 +124,50 @@ class cpuInfo(object):
         self.modelName = modelName
 
 
-def byteToGb(byteNumber):
-    # b   kb     mb      gb
-    return str(format(byteNumber / 1024 / 1024 / 1024, '.3'))
+def pid_info(pid, details):
+    """
+    使用psutil 探测指定pid的综合信息 方便判断问题节点
+    https://psutil.readthedocs.io/en/latest/#process-class
+    获取对应id的进程综合信息
+    cpu、内存、磁盘、文件描述符等等信息
+    :return:
+    """
+    p = psutil.Process(pid)
+    file_mem_map_info_str = ""
+    for m in p.memory_maps():
+        file_mem_map_info_str = file_mem_map_info_str + "\r\n" + m[0] + "使用rss:{},size:{}".format(
+            byte_length_format(m[1]),
+            byte_length_format(m[2]))
+
+    mem_full_info = p.memory_full_info()
+    mem_full_info_str = "使用总内存大小{},swap大小{}".format(byte_length_format(mem_full_info[8]),
+                                                    byte_length_format(mem_full_info[9]))
+
+    base_str = """
+PID:{}
+name:{}    
+执行用户:{}
+进程可执行文件路径:{}
+进程使用的内存大小信息:{}
+内存引用文件占用内存信息:{}
+此进程当前打开的文件描述符数:{}
+此进程当前使用的线程数:{}
+此进程和总物理内存比例:{}
+进程打开的套接字连接:{}
+""".format(p.pid,
+           p.name(),
+           p.username(),
+           p.exe(),
+           mem_full_info_str,
+           file_mem_map_info_str,
+           p.num_fds(),
+           p.num_threads(),
+           p.memory_percent(),
+           p.connections()
+           )
+    click.echo(base_str)
+    if details:
+        click.echo("详细信息:\r\n" + json.dumps(p.as_dict(), indent=1, separators=(', ', ': '), ensure_ascii=False))
 
 
 def detect():
@@ -155,7 +200,8 @@ def detect_mem():
     mem_info = """
     物理内存:{}/{},{}
     虚拟内存:{}/{},{}
-    """.format(byteToGb(v_mem.used()), byteToGb(v_mem.total()), 0, byteToGb(s_mem.used), byteToGb(s_mem.total), 0)
+    """.format(byte_length_format(v_mem.used()), byte_length_format(v_mem.total()), 0, byte_length_format(s_mem.used),
+               byte_length_format(s_mem.total), 0)
     click.echo(mem_info)
 
 
@@ -173,3 +219,34 @@ def detect_file_desc():
 
 def detect_io():
     pass
+
+
+def mem_info(top, pid, details):
+    p_arr = []
+    if pid is not None:
+        p_arr.append(psutil.Process(pid))
+    else:
+        for p in psutil.process_iter():
+            p_arr.append(p)
+
+    mem_info_arr = []
+    for p in p_arr:
+        for m in p.memory_maps():
+            mem_info_arr.append(m)
+
+    # 过滤 anon  heap  stack 数据
+    mem_info_arr = [t for t in mem_info_arr if not (t[0] == '[anon]' or t[0] == '[heap]' or t[0] == '[stack]')]
+    mem_info_arr.sort(key=lambda t: t[2], reverse=True)
+    mem_info_arr = mem_info_arr[:top]
+
+    # 创建表格
+    t_table = PrettyTable(['file', 'rss', 'size'])
+    for i, m in enumerate(mem_info_arr):
+        t_table.add_row([m[0], byte_length_format(m[1]), byte_length_format(m[2])])
+        if details:
+            click.echo("详细信息:\r\n" + json.dumps(m, indent=1, separators=(', ', ': '), ensure_ascii=False))
+    # 设置对齐方式
+    t_table.align = "l"
+    # 设置表格最长列
+    t_table.max_width = 80
+    click.echo(t_table)
